@@ -8,7 +8,7 @@ package Object::Pad;
 use strict;
 use warnings;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Carp;
 
@@ -262,6 +262,50 @@ sub Object::Pad::UNIVERSAL::BUILDALL
    }
 }
 
+=head1 WITH OTHER MODULES
+
+=head2 Syntax::Keyword::Dynamically
+
+A cross-module integration test asserts that C<dynamically> works correctly
+on object instance slots:
+
+   use Object::Pad;
+   use Syntax::Keyword::Dynamically;
+
+   class Container {
+      has $value = 1;
+
+      method example {
+         dynamically $value = 2;
+         ,..
+         # value is restored to 1 on return from this method
+      }
+   }
+
+=head2 Future::AsyncAwait
+
+As of L<Future::AsyncAwait> version 0.38 and L<Object::Pad> version 0.15, both
+modules now use L<XS::Parse::Sublike> to parse blocks of code. Because of this
+the two modules can operate together and allow class methods to be written as
+async subs which await expressions:
+
+   use Future::AsyncAwait;
+   use Object::Pad;
+
+   class Example
+   {
+      async method perform($block)
+      {
+         say "$self is performing code";
+         await $block->();
+         say "code finished";
+      }
+   }
+
+These three modules combine; there is additionally a cross-module test to
+ensure that object instance slots can be C<dynamically> set during a suspended
+C<async method>.
+
 =head1 DESIGN TODOs
 
 The following points are details about the design of pad slot-based object
@@ -318,6 +362,12 @@ Work out why C<no indirect> doesn't appear to work properly before perl 5.20.
 
 =item *
 
+Work out why we don't get a C<Subroutine new redefined at ...> warning if we
+
+  sub new { ... }
+
+=item *
+
 The C<local> modifier does not work on slot variables, because they appear to
 be regular lexicals to the parser at that point. A workaround is to use
 L<Syntax::Keyword::Dynamically> instead:
